@@ -26,7 +26,13 @@
 #include <stdlib.h>
 
 #include <glib.h>
-#include <girepository.h>
+
+#if GLIB_CHECK_VERSION(2, 85, 0)
+# include <girepository/girepository.h>
+#else
+# include <girepository.h>
+#endif
+
 #include <testing-util.h>
 
 #include "testing.h"
@@ -37,6 +43,7 @@ testing_init (int    *argc,
 {
   GError *error = NULL;
   static gboolean initialized = FALSE;
+  GIRepository *repository;
 
   if (initialized)
     return;
@@ -48,10 +55,18 @@ testing_init (int    *argc,
   /* Must be after g_test_init() changes the log settings*/
   testing_util_init ();
 
-  g_irepository_require_private (g_irepository_get_default (),
+  G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+#if GLIB_CHECK_VERSION(2, 85, 0)
+  repository = gi_repository_dup_default ();
+  gi_repository_require_private (repository,
+#else
+  repository = g_object_ref (g_irepository_get_default ());
+  g_irepository_require_private (repository,
+#endif
                                  BUILDDIR "/tests/libpeas/introspection",
                                  "Introspection", API_VERSION_S, 0, &error);
   g_assert_no_error (error);
+  g_clear_object (&repository);
 
   initialized = TRUE;
 }
@@ -72,9 +87,9 @@ testing_engine_new_full (gboolean nonglobal_loaders)
                               "*info-missing-name.plugin*");
   testing_util_push_log_hook ("*Error loading *info-missing-name.plugin*");
 
-  testing_util_push_log_hook ("*Unkown 'Loader' in "
-                              "*unkown-loader.plugin* does-not-exist");
-  testing_util_push_log_hook ("*Error loading *unkown-loader.plugin*");
+  testing_util_push_log_hook ("*Unknown 'Loader' in "
+                              "*unknown-loader.plugin* does-not-exist");
+  testing_util_push_log_hook ("*Error loading *unknown-loader.plugin*");
 
   testing_util_push_log_hook ("Bad plugin file '"
                               BUILDDIR "*" G_DIR_SEPARATOR_S "embedded*.plugin': "
